@@ -95,10 +95,6 @@ class _int_marker(int):
     pass
 
 
-class _bool_marker:
-    pass
-
-
 class Adjustments:
     """This class contains tunable parameters."""
 
@@ -147,7 +143,7 @@ class Adjustments:
     # TCP port to listen on
     port = _int_marker(8080)
 
-    listen = ["{}:{}".format(host, port)]
+    listen = [f"{host}:{port}"]
 
     # number of threads available for tasks
     threads = 4
@@ -180,9 +176,8 @@ class Adjustments:
     # proxy server to filter invalid headers
     log_untrusted_proxy_headers = False
 
-    # Should waitress clear any proxy headers that are not deemed trusted from
-    # the environ? Change to True by default in 2.x
-    clear_untrusted_proxy_headers = _bool_marker
+    # Changed this parameter to True by default in 3.x
+    clear_untrusted_proxy_headers = True
 
     # default ``wsgi.url_scheme`` value
     url_scheme = "http"
@@ -295,7 +290,6 @@ class Adjustments:
     server_name = "waitress.invalid"
 
     def __init__(self, **kw):
-
         if "listen" in kw and ("host" in kw or "port" in kw):
             raise ValueError("host or port may not be set if listen is set.")
 
@@ -327,7 +321,7 @@ class Adjustments:
         if not isinstance(self.host, _str_marker) or not isinstance(
             self.port, _int_marker
         ):
-            self.listen = ["{}:{}".format(self.host, self.port)]
+            self.listen = [f"{self.host}:{self.port}"]
 
         enabled_families = socket.AF_UNSPEC
 
@@ -445,15 +439,6 @@ class Adjustments:
             )
             self.trusted_proxy_headers = {"x-forwarded-proto"}
 
-        if self.clear_untrusted_proxy_headers is _bool_marker:
-            warnings.warn(
-                "In future versions of Waitress clear_untrusted_proxy_headers will be "
-                "set to True by default. You may opt-out by setting this value to "
-                "False, or opt-in explicitly by setting this to True.",
-                DeprecationWarning,
-            )
-            self.clear_untrusted_proxy_headers = False
-
         self.listen = wanted_sockets
 
         self.check_sockets(self.sockets)
